@@ -9,13 +9,16 @@ NULL
 #' \code{\link[dplyr]{left_join}()} and \code{\link{replace_na}} that's
 #' useful for completing missing combinations of data.
 #'
+#' If you supply \code{fill}, these values will also replace existing
+#' explicit missing values in the data set.
+#'
 #' @inheritParams complete_
 #' @inheritParams expand
 #' @seealso \code{\link{complete_}} for a version that uses regular evaluation
 #'   and is suitable for programming with.
 #' @export
 #' @examples
-#' library(dplyr)
+#' library(dplyr, warn.conflicts = FALSE)
 #' df <- data_frame(
 #'   group = c(1:2, 1),
 #'   item_id = c(1:2, 2),
@@ -57,3 +60,8 @@ complete_.data.frame <- function(data, cols, fill = list(), ...) {
 
   full
 }
+
+#' @export
+complete_.grouped_df <- function(data, cols, fill = list(), ...) {
+  regroup(NextMethod(), data)
+}
